@@ -27,7 +27,6 @@
 #include "phonenumbers/base/logging.h"
 #include "phonenumbers/stringutil.h"
 
-#include "absl/strings/str_replace.h"
 #include "absl/strings/string_view.h"
 namespace i18n {
 namespace phonenumbers {
@@ -78,14 +77,14 @@ bool DispatchRE2Call(Function regex_function,
 // when they escape dollar-signs.
 string TransformRegularExpressionToRE2Syntax(const string& regex) {
   string re2_regex(regex);
-  if (absl::StrReplaceAll({{"$", "\\"}}, &re2_regex) == 0) {
+  if (GlobalReplaceSubstring("$", "\\", &re2_regex) == 0) {
     return regex;
   }
   // If we replaced a dollar sign with a backslash and there are now two
   // backslashes in the string, we assume that the dollar-sign was previously
   // escaped and that we need to retain it. To do this, we replace pairs of
   // backslashes with a dollar sign.
-  absl::StrReplaceAll({{"\\\\", "$"}}, &re2_regex);
+  GlobalReplaceSubstring("\\\\", "$", &re2_regex);
   return re2_regex;
 }
 
@@ -130,7 +129,7 @@ class RE2RegExp : public RegExp {
                              matched_string, NULL, NULL, NULL, NULL, NULL);
     } else {
       return DispatchRE2Call(RE2::PartialMatchN, input_string, utf8_regexp_,
-                             matched_string, NULL, NULL), NULL, NULL, NULL);
+                             matched_string, NULL, NULL, NULL, NULL, NULL);
     }
   }
 
